==> mx-cleanup_19.4.tar.xz: mx-cleanup-19.4/translations/mx-cleanup_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="51"/>
        <location filename="../mainwindow.cpp" line="262"/>
        <location filename="../mainwindow.cpp" line="309"/>
        <source>MX Cleanup</source>
        <translation>MX Limpador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>Clean Folders</source>
        <translation>Pastas a Limpar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="86"/>
        <source>Delete Logs</source>
        <translation>Eliminar os registos (Logs)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="98"/>
        <source>Old logs</source>
        <translation>Registros antigos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>All logs</source>
        <translation>Todos os registros</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="130"/>
        <location filename="../mainwindow.ui" line="387"/>
        <location filename="../mainwindow.ui" line="451"/>
        <source>Don&apos;t empty</source>
        <translation>Não esvazie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="192"/>
        <source>Display help </source>
        <translation>Exibir a ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="195"/>
        <source>Help</source>
        <translation>Ajudas várias (em inglês)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="202"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="231"/>
        <source>About this application</source>
        <translation>Sobre esta aplicação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="234"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="241"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="273"/>
        <source>Quit application</source>
        <translation>Sair da aplicação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="276"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="321"/>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="349"/>
        <source>Empty Trash</source>
        <translation>Esvaziar o Lixo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="364"/>
        <source>Selected user</source>
        <translation>Usuário selecionado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="380"/>
        <source>All users</source>
        <translation>Todos os usuários</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="416"/>
        <source>Clear APT Cache</source>
        <translation>Limpar a memória cache APT</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="428"/>
        <source>Old files</source>
        <translation>Arquivos antigos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="444"/>
        <source>All files</source>
        <translation>Todos os arquivos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="480"/>
        <source>Free Disk Space for User</source>
        <translation>Espaço Livre em Disco para o Utilizador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="492"/>
        <location filename="../mainwindow.ui" line="505"/>
        <source>Select user to repair</source>
        <translation>Selecionar utilizador a reparar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <source>Select user:</source>
        <translation>Selecione o usuário:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="524"/>
        <source>Graphical Tool for Analyzing Disk Usage</source>
        <translation>Ferramenta gráfica para analisar o uso do disco</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="530"/>
        <source>Run Disk Usage Analyzer</source>
        <translation>Executar o analisador de uso de disco</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="544"/>
        <source>Schedule</source>
        <translation>Agendar limpeza automática</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="556"/>
        <source>No automatic clean</source>
        <translation>Nunca</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="563"/>
        <source>Daily</source>
        <translation>Diariamente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="570"/>
        <source>Weekly</source>
        <translation>Semanalmente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="577"/>
        <source>Monthly</source>
        <translation>Mensalmente</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="253"/>
        <source>Done</source>
        <translation>Concluído</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="254"/>
        <source>Cleanup command done</source>
        <translation>Comando de limpeza feito</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="255"/>
        <source>%1 MiB were freed</source>
        <translation>%1 MiB foram limpos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="262"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="263"/>
        <source>Version: </source>
        <translation>Versão:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="264"/>
        <source>Quick and safe removal of old files</source>
        <translation>Remoção rápida e segura de arquivos antigos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="266"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Direitos de Autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="267"/>
        <location filename="../mainwindow.cpp" line="277"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="268"/>
        <source>Changelog</source>
        <translation>Relatório de alterações</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="269"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="290"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>You must run this program as root.</source>
        <translation>Este programa deve ser executado como administrador</translation>
    </message>
</context>
</TS>

==> mx-cleanup_20.8.tar.xz: mx-cleanup-20.8/translations/mx-cleanup_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="54"/>
        <location filename="../mainwindow.cpp" line="324"/>
        <location filename="../mainwindow.cpp" line="370"/>
        <source>MX Cleanup</source>
        <translation>MX Limpador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>Clean Folders</source>
        <translation>Pastas a Limpar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="119"/>
        <source>Display help </source>
        <translation>Exibir a ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="122"/>
        <source>Help</source>
        <translation>Ajudas várias (em inglês)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="129"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <source>About this application</source>
        <translation>Sobre esta aplicação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="161"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="200"/>
        <source>Quit application</source>
        <translation>Sair da aplicação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="210"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="276"/>
        <source>Empty Trash</source>
        <translation>Esvaziar o Lixo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="282"/>
        <source>Trash older than:</source>
        <translation>Lixo com mais de:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <location filename="../mainwindow.ui" line="426"/>
        <location filename="../mainwindow.ui" line="625"/>
        <source>Don&apos;t empty</source>
        <translation>Não esvaziar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="299"/>
        <location filename="../mainwindow.ui" line="657"/>
        <source> days</source>
        <translation>dias</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="318"/>
        <source>All users</source>
        <translation>Todos os usuários</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="337"/>
        <source>Selected user</source>
        <translation>Usuário selecionado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="385"/>
        <source>Clear APT Cache</source>
        <translation>Limpar a memória cache APT</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="397"/>
        <source>Old files</source>
        <translation>Arquivos antigos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="416"/>
        <source>All files</source>
        <translation>Todos os arquivos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="458"/>
        <source>Free Disk Space for User</source>
        <translation>Espaço Livre em Disco para o Utilizador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="470"/>
        <location filename="../mainwindow.ui" line="483"/>
        <source>Select user to repair</source>
        <translation>Selecionar utilizador a reparar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="486"/>
        <source>Select user:</source>
        <translation>Selecione o usuário:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="502"/>
        <source>Graphical Tool for Analyzing Disk Usage</source>
        <translation>Ferramenta gráfica para analisar o uso do disco</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <source>Run Disk Usage Analyzer</source>
        <translation>Executar o analisador de uso de disco</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="522"/>
        <source>Schedule</source>
        <translation>Agendar limpeza automática</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="534"/>
        <source>No automatic clean</source>
        <translation>Nunca</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="541"/>
        <source>Daily</source>
        <translation>Diariamente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="548"/>
        <source>Weekly</source>
        <translation>Semanalmente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="555"/>
        <source>Monthly</source>
        <translation>Mensalmente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="584"/>
        <source>Delete Logs</source>
        <translation>Eliminar os registros (Logs)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="609"/>
        <source>All logs</source>
        <translation>Todos os registros</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="641"/>
        <source>Old logs</source>
        <translation>Registros antigos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="676"/>
        <source>Logs older than:</source>
        <translation>Registros com mais de:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="315"/>
        <source>Done</source>
        <translation>Concluído</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="316"/>
        <source>Cleanup command done</source>
        <translation>Comando de limpeza feito</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="317"/>
        <source>%1 MiB were freed</source>
        <translation>%1 MiB foram limpos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="324"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="325"/>
        <source>Version: </source>
        <translation>Versão:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>Quick and safe removal of old files</source>
        <translation>Remoção rápida e segura de arquivos antigos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="328"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Direitos de Autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="329"/>
        <location filename="../mainwindow.cpp" line="339"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="330"/>
        <location filename="../mainwindow.cpp" line="345"/>
        <source>Changelog</source>
        <translation>Relatório de alterações</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="331"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="352"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>You must run this program as root.</source>
        <translation>Este programa deve ser executado como administrador</translation>
    </message>
</context>
</TS>
